nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Autoclkgateoverride

Struct Autoclkgateoverride 

#[repr(transparent)]
pub struct Autoclkgateoverride(pub u32);
Control automatic clock gating

Tuple Fields

0: u32

Implementations

Source

impl Autoclkgateoverride

pub const fn rom(&self) -> bool

Control automatic clock gating of ROM controller.

pub const fn set_rom(&mut self, val: bool)

Control automatic clock gating of ROM controller.

pub const fn ramx_ctrl(&self) -> bool

Control automatic clock gating of RAMX controller.

pub const fn set_ramx_ctrl(&mut self, val: bool)

Control automatic clock gating of RAMX controller.

pub const fn ram0_ctrl(&self) -> bool

Control automatic clock gating of RAM0 controller.

pub const fn set_ram0_ctrl(&mut self, val: bool)

Control automatic clock gating of RAM0 controller.

pub const fn ram1_ctrl(&self) -> bool

Control automatic clock gating of RAM1 controller.

pub const fn set_ram1_ctrl(&mut self, val: bool)

Control automatic clock gating of RAM1 controller.

pub const fn ram2_ctrl(&self) -> bool

Control automatic clock gating of RAM2 controller.

pub const fn set_ram2_ctrl(&mut self, val: bool)

Control automatic clock gating of RAM2 controller.

pub const fn ram3_ctrl(&self) -> bool

Control automatic clock gating of RAM3 controller.

pub const fn set_ram3_ctrl(&mut self, val: bool)

Control automatic clock gating of RAM3 controller.

pub const fn ram4_ctrl(&self) -> bool

Control automatic clock gating of RAM4 controller.

pub const fn set_ram4_ctrl(&mut self, val: bool)

Control automatic clock gating of RAM4 controller.

pub const fn sync0_apb(&self) -> bool

Control automatic clock gating of synchronous bridge controller 0.

pub const fn set_sync0_apb(&mut self, val: bool)

Control automatic clock gating of synchronous bridge controller 0.

pub const fn sync1_apb(&self) -> bool

Control automatic clock gating of synchronous bridge controller 1.

pub const fn set_sync1_apb(&mut self, val: bool)

Control automatic clock gating of synchronous bridge controller 1.

pub const fn crcgen(&self) -> bool

Control automatic clock gating of CRCGEN controller.

pub const fn set_crcgen(&mut self, val: bool)

Control automatic clock gating of CRCGEN controller.

pub const fn sdma0(&self) -> bool

Control automatic clock gating of DMA0 controller.

pub const fn set_sdma0(&mut self, val: bool)

Control automatic clock gating of DMA0 controller.

pub const fn sdma1(&self) -> bool

Control automatic clock gating of DMA1 controller.

pub const fn set_sdma1(&mut self, val: bool)

Control automatic clock gating of DMA1 controller.

pub const fn usb0(&self) -> bool

Control automatic clock gating of USB controller.

pub const fn set_usb0(&mut self, val: bool)

Control automatic clock gating of USB controller.

pub const fn syscon(&self) -> bool

Control automatic clock gating of synchronous system controller registers bank.

pub const fn set_syscon(&mut self, val: bool)

Control automatic clock gating of synchronous system controller registers bank.

pub const fn enableupdate(&self) -> Enableupdate

The value 0xC0DE must be written for AUTOCLKGATEOVERRIDE registers fields updates to have effect.

pub const fn set_enableupdate(&mut self, val: Enableupdate)

The value 0xC0DE must be written for AUTOCLKGATEOVERRIDE registers fields updates to have effect.