nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Cpu0stckcal

Struct Cpu0stckcal 

#[repr(transparent)]
pub struct Cpu0stckcal(pub u32);
System tick calibration for secure part of CPU0

Tuple Fields

0: u32

Implementations

Source

impl Cpu0stckcal

pub const fn tenms(&self) -> u32

Reload value for 10ms (100Hz) timing, subject to system clock skew errors. If the value reads as zero, the calibration value is not known.

pub const fn set_tenms(&mut self, val: u32)

Reload value for 10ms (100Hz) timing, subject to system clock skew errors. If the value reads as zero, the calibration value is not known.

pub const fn skew(&self) -> bool

Initial value for the Systick timer.

pub const fn set_skew(&mut self, val: bool)

Initial value for the Systick timer.

pub const fn noref(&self) -> bool

Indicates whether the device provides a reference clock to the processor: 0 = reference clock provided; 1 = no reference clock provided.

pub const fn set_noref(&mut self, val: bool)

Indicates whether the device provides a reference clock to the processor: 0 = reference clock provided; 1 = no reference clock provided.