#[repr(transparent)]pub struct Nmisrc(pub u32);Expand description
NMI Source Select
Tuple Fields
0: u32Implementations
Sourceimpl Nmisrc
impl Nmisrc
Sourcepub const fn irqcpu0(&self) -> u8
pub const fn irqcpu0(&self) -> u8
The IRQ number of the interrupt that acts as the Non-Maskable Interrupt (NMI) for the CPU0, if enabled by NMIENCPU0.
Sourcepub const fn set_irqcpu0(&mut self, val: u8)
pub const fn set_irqcpu0(&mut self, val: u8)
The IRQ number of the interrupt that acts as the Non-Maskable Interrupt (NMI) for the CPU0, if enabled by NMIENCPU0.
Sourcepub const fn irqcpu1(&self) -> u8
pub const fn irqcpu1(&self) -> u8
The IRQ number of the interrupt that acts as the Non-Maskable Interrupt (NMI) for the CPU1, if enabled by NMIENCPU1.
Sourcepub const fn set_irqcpu1(&mut self, val: u8)
pub const fn set_irqcpu1(&mut self, val: u8)
The IRQ number of the interrupt that acts as the Non-Maskable Interrupt (NMI) for the CPU1, if enabled by NMIENCPU1.
Sourcepub const fn nmiencpu1(&self) -> bool
pub const fn nmiencpu1(&self) -> bool
Write a 1 to this bit to enable the Non-Maskable Interrupt (NMI) source selected by IRQCPU1.
Sourcepub const fn set_nmiencpu1(&mut self, val: bool)
pub const fn set_nmiencpu1(&mut self, val: bool)
Write a 1 to this bit to enable the Non-Maskable Interrupt (NMI) source selected by IRQCPU1.
Sourcepub const fn nmiencpu0(&self) -> bool
pub const fn nmiencpu0(&self) -> bool
Write a 1 to this bit to enable the Non-Maskable Interrupt (NMI) source selected by IRQCPU0.
Sourcepub const fn set_nmiencpu0(&mut self, val: bool)
pub const fn set_nmiencpu0(&mut self, val: bool)
Write a 1 to this bit to enable the Non-Maskable Interrupt (NMI) source selected by IRQCPU0.