#[repr(transparent)]pub struct Autoclkgateoverride(pub u32);Expand description
Control automatic clock gating
Tuple Fields
0: u32Implementations
Sourceimpl Autoclkgateoverride
impl Autoclkgateoverride
Sourcepub const fn set_ramx_ctrl(&mut self, val: bool)
pub const fn set_ramx_ctrl(&mut self, val: bool)
Control automatic clock gating of RAMX controller.
Sourcepub const fn set_ram0_ctrl(&mut self, val: bool)
pub const fn set_ram0_ctrl(&mut self, val: bool)
Control automatic clock gating of RAM0 controller.
Sourcepub const fn set_ram1_ctrl(&mut self, val: bool)
pub const fn set_ram1_ctrl(&mut self, val: bool)
Control automatic clock gating of RAM1 controller.
Sourcepub const fn set_ram2_ctrl(&mut self, val: bool)
pub const fn set_ram2_ctrl(&mut self, val: bool)
Control automatic clock gating of RAM2 controller.
Sourcepub const fn set_ram3_ctrl(&mut self, val: bool)
pub const fn set_ram3_ctrl(&mut self, val: bool)
Control automatic clock gating of RAM3 controller.
Sourcepub const fn set_ram4_ctrl(&mut self, val: bool)
pub const fn set_ram4_ctrl(&mut self, val: bool)
Control automatic clock gating of RAM4 controller.
Sourcepub const fn sync0_apb(&self) -> bool
pub const fn sync0_apb(&self) -> bool
Control automatic clock gating of synchronous bridge controller 0.
Sourcepub const fn set_sync0_apb(&mut self, val: bool)
pub const fn set_sync0_apb(&mut self, val: bool)
Control automatic clock gating of synchronous bridge controller 0.
Sourcepub const fn sync1_apb(&self) -> bool
pub const fn sync1_apb(&self) -> bool
Control automatic clock gating of synchronous bridge controller 1.
Sourcepub const fn set_sync1_apb(&mut self, val: bool)
pub const fn set_sync1_apb(&mut self, val: bool)
Control automatic clock gating of synchronous bridge controller 1.
Sourcepub const fn set_crcgen(&mut self, val: bool)
pub const fn set_crcgen(&mut self, val: bool)
Control automatic clock gating of CRCGEN controller.
Sourcepub const fn set_sdma0(&mut self, val: bool)
pub const fn set_sdma0(&mut self, val: bool)
Control automatic clock gating of DMA0 controller.
Sourcepub const fn set_sdma1(&mut self, val: bool)
pub const fn set_sdma1(&mut self, val: bool)
Control automatic clock gating of DMA1 controller.
Sourcepub const fn syscon(&self) -> bool
pub const fn syscon(&self) -> bool
Control automatic clock gating of synchronous system controller registers bank.
Sourcepub const fn set_syscon(&mut self, val: bool)
pub const fn set_syscon(&mut self, val: bool)
Control automatic clock gating of synchronous system controller registers bank.
Sourcepub const fn enableupdate(&self) -> Enableupdate
pub const fn enableupdate(&self) -> Enableupdate
The value 0xC0DE must be written for AUTOCLKGATEOVERRIDE registers fields updates to have effect.
Sourcepub const fn set_enableupdate(&mut self, val: Enableupdate)
pub const fn set_enableupdate(&mut self, val: Enableupdate)
The value 0xC0DE must be written for AUTOCLKGATEOVERRIDE registers fields updates to have effect.